@@ -1,8 +1,6 @@
 package Plack::Middleware::REST::Util;
-{
-  $Plack::Middleware::REST::Util::VERSION = '0.03';
-}
-#ABSTRACT: Utility methods to create RESTful PSGI applications
+
+our $VERSION = '0.03';
 
 use Plack::Request;
 
@@ -28,21 +26,12 @@ sub request_uri {
 }
 
 1;
-
 __END__
 
-=pod
-
-=encoding UTF-8
-
 =head1 NAME
 
 Plack::Middleware::REST::Util - Utility methods to create RESTful PSGI applications
 
-=head1 VERSION
-
-version 0.03
-
 =head1 SYNOPSIS
 
     use Plack::Middleware::REST::Util;
@@ -52,15 +41,4 @@ version 0.03
     $uri = request_uri($env,$id) # resource identifier of modified request
     ($content => $type) = request_content($env); # send content and MIME type
 
-=head1 AUTHOR
-
-Jakob Voß <voss@gbv.de>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Jakob Voß.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
